from .auth import get_me
from .messages import send_message, send_photo, send_document, send_video, send_audio, send_voice, send_location, send_contact
from .chats import get_chat, get_chat_administrators, get_chat_members_count
from .inline import answer_inline_query
from .payments import answer_pre_checkout_query, answer_shipping_query
from .advanced import forward_message, copy_message, delete_message, edit_message_text, edit_message_caption, edit_message_media, edit_message_reply_markup
from .callbacks import answer_callback_query  # Add this line

__all__ = [
    'get_me',
    'send_message', 'send_photo', 'send_document', 'send_video', 'send_audio', 'send_voice', 'send_location', 'send_contact',
    'get_chat', 'get_chat_administrators', 'get_chat_members_count',
    'answer_inline_query', 'answer_callback_query',  # Add answer_callback_query here
    'answer_pre_checkout_query', 'answer_shipping_query',
    'forward_message', 'copy_message', 'delete_message', 'edit_message_text', 'edit_message_caption', 'edit_message_media', 'edit_message_reply_markup'
]
